// For licensing, see: http://hydrogen.knownspace.org/license.html

/**
 * AndEventConstraint.java
 */
package org.datamanager.constraint;

import org.datamanager.event.DataManagerEvent;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEventConstraint;

/**
 * AndEventConstraint matches all events that match both
 * of the EventConstraints given to it in its constructor.
 *
 * @author Matthew Farrellee
 */
public class AndEventConstraint
    extends AbstractEventConstraint
    {
    /**
     * The EventConstraints to use in the And.
     */
    private EventConstraint pEvent;
    /**
     * The EventConstraints to use in the And.
     */
    private EventConstraint qEvent;

    /**
     * Create a new AndEventConstraint to work on Events
     *
     * @param p An EventConstraint.
     * @param q An EventConstraint.
     */
    public AndEventConstraint(EventConstraint p, EventConstraint q)
        {
        this.pEvent = p;
        this.qEvent = q;
        }

    /**
     * Check to see if the given Event is valid or not.
     *
     * @param defendant An event to check.
     *
     * @return Whether the event was valid or not.
     */
    protected boolean describes(DataManagerEvent defendant)
                         throws DataManagerException
        {
        return (pEvent.accepts(defendant) && qEvent.accepts(defendant));
        }
    }