// For licensing, see: http://hydrogen.knownspace.org/license.html

/**
 * NotEventConstraint.java
 */
package org.datamanager.constraint;

import org.datamanager.event.DataManagerEvent;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEventConstraint;

/**
 * Logical Not for EventConstraints.
 *
 * @author Matthew Farrellee
 */
public class NotEventConstraint
    extends AbstractEventConstraint
    {
    /**
     * The EventConstraints to negate.
     */
    private EventConstraint negatedEvent;

    /**
     * Create a NotEventConstraint to work on Events.
     *
     * @param negated EventConstraint to negate.
     */
    public NotEventConstraint(EventConstraint negated)
        {
        this.negatedEvent = negated;
        }

    /**
     * Check to see if the event satisfies the EventConstraint
     * given in the constructor and then negate the result.
     *
     * @param defendant An event to check.
     *
     * @return Whether the event is valid or not.
     */
    protected boolean describes(DataManagerEvent defendant)
                         throws DataManagerException
        {
        return !negatedEvent.accepts(defendant);
        }
    }