// For licensing, see: http://hydrogen.knownspace.org/license.html

/**
 * OrEntityConstraint.java
 */
package org.datamanager.constraint;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEntityConstraint;
import org.datamanager.kernel.Entity;

/**
 * OrEntityConstraint takes two EntityConstraints in its constructor.
 * It matches all entities that match one or both of those constraints.
 *
 * @author Matthew Farrellee
 */
public class OrEntityConstraint
    extends AbstractEntityConstraint
    {
    /**
     * The EntityConstraints to use in the Or.
     */
    private EntityConstraint pEntity;
    /**
     * The EntityConstraints to use in the Or.
     */
    private EntityConstraint qEntity;

    /**
     * Create a new OrEntityConstraint to work on Entities
     *
     * @param p An EntityConstraint.
     * @param q An EntityConstraint.
     */
    public OrEntityConstraint(EntityConstraint p, EntityConstraint q)
        {
        this.pEntity = p;
        this.qEntity = q;
        }

    /**
     * Check to see if the given Entity is valid or not.
     *
     * @param defendant An Entity to check.
     *
     * @return Whether the Entity was valid or not.
     */
    protected boolean describes(Entity defendant)
                         throws DataManagerException
        {
        return (pEntity.accepts(defendant) || qEntity.accepts(defendant));
        }
    }