// For licensing, see: http://hydrogen.knownspace.org/license.html

/**
 * OrEventConstraint.java
 */
package org.datamanager.constraint;

import org.datamanager.event.DataManagerEvent;

import org.datamanager.exception.DataManagerException;

import org.datamanager.kernel.AbstractEventConstraint;

/**
 * OrEventConstraint takes two EventConstraints in its constructor.
 * It matches all events that match one or both of those constraints.
 *
 * @author Matthew Farrellee
 */
public class OrEventConstraint
    extends AbstractEventConstraint
    {
    /**
     * The EventConstraints to use in the Or.
     */
    private EventConstraint pEvent;
    /**
     * The EventConstraints to use in the Or.
     */
    private EventConstraint qEvent;

    /**
     * Create a new OrEventConstraint to work on Events
     *
     * @param p An EventConstraint.
     * @param q An EventConstraint.
     */
    public OrEventConstraint(EventConstraint p, EventConstraint q)
        {
        this.pEvent = p;
        this.qEvent = q;
        }

    /**
     * Check to see if the given event is valid or not.
     *
     * @param defendant An event to check.
     *
     * @return Whether the event was valid or not.
     */
    protected boolean describes(DataManagerEvent defendant)
                         throws DataManagerException
        {
        return (pEvent.accepts(defendant) || qEvent.accepts(defendant));
        }
    }