// For licensing, see: http://hydrogen.knownspace.org/license.html
package org.datamanager.event;

import org.datamanager.constraint.EntityConstraint;

import org.datamanager.event.DataManagerEventAdapter;
import org.datamanager.event.PoolEvent;

import org.datamanager.kernel.EventGenerator;

/**
 * This event is fired when <code>Pool.search()</code>
 * is invoked.
 *
 * @author Matthew Farrellee
 */
public class SearchPoolEvent
    extends DataManagerEventAdapter
    implements PoolEvent
    {
    /**
     * The <code>EntityConstraint</code> that was used in the search.
     */
    private EntityConstraint constraint;

    /**
     * The public constructor used to create a <code>SearchPoolEvent</code>.
     *
     * @param source The source of this event. Usually 'this.'
     * @param constraint The <code>EntityConstraint</code> that was used
     *                   for the search.
     */
    public SearchPoolEvent(EventGenerator source, EntityConstraint constraint)
        {
        super(source);
        this.constraint = constraint;
        }

    /**
     * Report the <code>EntityConstraint</code> that was used in the search.
     *
     * @return The <code>EntityConstraint</code> used for the search.
     */
    public EntityConstraint getConstraint()
        {
        return constraint;
        }

    /**
     * A toString() method to provide a meaningful <code>String</code>
     * representation of this event.
     *
     * @return A meaningful <code>String</code> representation
     *         of this event.
     */
    public String toString()
        {
        return "SearchPoolEvent[[source: " + source + "]" + "[constraint: " + 
               constraint + "]" + "[time: " + time + "]]";
        }
    }