// For licensing, see: http://hydrogen.knownspace.org/license.html
package org.datamanager.event;

import org.datamanager.constraint.EventConstraint;

import org.datamanager.event.DataManagerEventAdapter;
import org.datamanager.event.KernelEvent;

import org.datamanager.kernel.EventGenerator;
import org.datamanager.kernel.EventHandler;

/**
 * This event is fired when
 * <code>EventGenerator.subscribe()</code> is invoked.
 *
 * @author Matthew Farrellee
 */
public class SubscribeEventGeneratorEvent
    extends DataManagerEventAdapter
    implements KernelEvent
    {
    /**
     * The <code>EventConstraint</code> that was subscribed.
     */
    private EventConstraint constraint;
    /**
     * The <code>EventHandler</code> that was subscribed.
     */
    private EventHandler handler;

    /**
     * The public constructor used to create a
     * <code>SubscribeEventGeneratorEvent</code>.
     *
     * @param source The source of this event. Usually 'this.'
     * @param handler The <code>EventHandler</code> that was
     *                subscribed.
     * @param constraint The <code>EventConstraint</code> that was
     *                   subscribed.
     */
    public SubscribeEventGeneratorEvent(EventGenerator source, 
                                        EventHandler handler, 
                                        EventConstraint constraint)
        {
        super(source);
        this.handler = handler;
        this.constraint = constraint;
        }

    /**
     * Report the <code>EventHandler</code> that was subscribed.
     *
     * @return The <code>EventHandler</code> that was subscribed.
     */
    public EventHandler getEventHandler()
        {
        return handler;
        }

    /**
     * Report the <code>EventConstraint</code> that was subscribed.
     *
     * @return The <code>EventConstraint</code> that was subscribed.
     */
    public EventConstraint getConstraint()
        {
        return constraint;
        }

    /**
     * A toString() method to provide a meaningful <code>String</code>
     * representation of this event.
     *
     * @return A meaningful <code>String</code> representation
     *         of this event.
     */
    public String toString()
        {
        return "SubscribeEventGeneratorEvent[[source: " + source + "]" + 
               "[eventHandler: " + handler + "]" + "[eventconstraint: " + 
               constraint + "]" + "[time: " + time + "]]";
        }
    }