// For licensing, see: http://hydrogen.knownspace.org/license.html
///////////////////////////////////////////////////////////////////////////////
// 2002-10-13 mml
// Created file.
///////////////////////////////////////////////////////////////////////////////
package org.datamanager.persistence.serializable;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.OutputStream;
import java.io.Serializable;

import java.lang.ClassNotFoundException;
import java.lang.RuntimeException;

import org.datamanager.persistence.DataAccessObject;

/**
 * Supports persistence of objects across sessions using plain old
 * serialization.  All objects persisted with this class must implement
 * Serializable.
 *
 * @author Matt Liggett
 */
public class SerializableDataAccessObject
    implements DataAccessObject
    {
    public void persist(Object object, File file)
        {
        try
            {
            persist(object, new FileOutputStream(file));
            }
        catch (FileNotFoundException exception)
            {
            exception.printStackTrace();
            throw new RuntimeException(exception);
            }
        }

    public Object restore(File fileLocation)
        {
        Object result = null;

        try
            {
            result = restore(new FileInputStream(fileLocation));
            }
        catch (FileNotFoundException exception)
            {
            exception.printStackTrace();
            throw new RuntimeException(exception);
            }

        return result;
        }

    public void persist(Object object, OutputStream outputStream)
        {
        try
            {
            (new ObjectOutputStream(outputStream)).writeObject(object);
            }
        catch (IOException exception)
            {
            exception.printStackTrace();
            throw new RuntimeException(exception);
            }
        }

    public Object restore(InputStream inputStream)
        {
        Object result = null;

        try
            {
            result = (new ObjectInputStream(inputStream)).readObject();
            }
        catch (IOException exception)
            {
            exception.printStackTrace();
            throw new RuntimeException(exception);
            }
        catch (ClassNotFoundException exception)
            {
            exception.printStackTrace();
            throw new RuntimeException(exception);
            }

        return result;
        }
    }