// For licensing, see: http://hydrogen.knownspace.org/license.html
package org.datamanager.persistence.xml;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.OutputStreamWriter;

import java.lang.reflect.*;

import java.util.Properties;

import javax.xml.parsers.*;
import javax.xml.transform.*;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.datamanager.persistence.DataAccessObject;

import org.w3c.dom.*;

import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

/**
 * Implement the DataAccessObject
 *
 * @author xi rao & Jason Lynn Baumgartner
 */
public class XMLDataAccessObject
    implements DataAccessObject
    {
    public static final String JAVA_VERSION = "1.4.0";
    public static final String JAVA = "java";
    public static final String CLASS = "class";
    public static final String VERSION = "version";
    public static final String OBJECT = "object";
    public static final String PROPERTY = "property";
    public static final String STRING = "string";
    public static final String ID = "id";
    public static final String METHOD = "method";
    public static final String VOID = "void";
    public static final String STRING_PACKAGE = "java.lang.String";
    public static final String NULL = "null";
    public static final String ARRAY = "array";
    public static final String IDREF = "idref";
    public static final String BOOLEAN = "boolean";
    public static final String BYTE = "byte";
    public static final String CHAR = "char";
    public static final String SHORT = "short";
    public static final String INT = "int";
    public static final String LONG = "long";
    public static final String FLOAT = "float";
    public static final String DOUBLE = "double";
    public static final String ENCODING = "UTF-16";

    public XMLDataAccessObject()
        {
        }

    /**
     * write object to xml file. It get the object state out and keep them in xml file on disk.
     * @param object Object instance of any object with empty constructor
     * @param fileLocation path/file name to keep xml file on disk
     */
    public void persist(Object object, File fileLocation)
        {
        XMLDataPersistence xmlDataPersistence = new XMLDataPersistence();
        Document document = xmlDataPersistence.getXMLRepresentation(object);
        write(document, fileLocation);
        }

    /**
     * read the xml file and rebuild the object with state, which keep in the xml file one disk
     * @param fileLocation path/file name to read the xml file from disk
     * @return Object instance of rebuild Object, the client require to cast it.
     */
    public Object restore(File fileLocation)
        {
        XMLDataRestore xmlDataRestore = new XMLDataRestore();
        Document document = XMLDocument.getXMLDocument(fileLocation);

        return xmlDataRestore.getRestoredObject(document);
        }

    // write XML document to disk with assigned locationtion and file name
    private void write(Document document, File file)
        {
        try
            {
            if (file.exists())
                {
                file.delete();
                }

            TransformerFactory tFactory = TransformerFactory.newInstance();
            Transformer transformer = tFactory.newTransformer();
            transformer.setOutputProperty(OutputKeys.ENCODING, ENCODING);

            DOMSource source = new DOMSource(document);

            //FileOutputStream fileOutputStream = new FileOutputStream(file);
            //OutputStreamWriter out = new OutputStreamWriter ( fileOutputStream, ENCODING );
            //StreamResult result=new StreamResult(out);
            StreamResult result = new StreamResult(file);
            transformer.transform(source, result);
            }
        catch (TransformerConfigurationException tce)
            {
            tce.printStackTrace();
            }
        catch (TransformerException te)
            {
            te.printStackTrace();
            } //catch (IOException ioe ) { ioe.printStackTrace();

        // }
        }

    /**
     * keep the object as a xml file in the disk
     * @param object any object
     * @param outputStream write to output stream
     */
    public void persist(Object object, OutputStream outputStream)
        {
        XMLDataPersistence xmlDataPersistence = new XMLDataPersistence();
        Document document = xmlDataPersistence.getXMLRepresentation(object);

        try
            {
            TransformerFactory tFactory = TransformerFactory.newInstance();
            Transformer transformer = tFactory.newTransformer();
            DOMSource source = new DOMSource(document);
            StreamResult result = new StreamResult(outputStream);
            transformer.transform(source, result);
            }
        catch (TransformerConfigurationException tce)
            {
            }
        catch (TransformerException te)
            {
            }
        }

    /**
     * return the instance object which store in the xml file
     * the client need to cast the return to the correct type.
     * @param inputStream read from input stream
     * @return an instance which restore state from the xml file
     */
    public Object restore(InputStream inputStream)
        {
        XMLDataRestore xmlDataRestore = new XMLDataRestore();
        Document document = XMLDocument.getXMLDocument(inputStream);

        return xmlDataRestore.getRestoredObject(document);
        }
    }