// For licensing, see: http://hydrogen.knownspace.org/license.html
package org.datamanager.persistence.xml.fieldtypes;

import java.lang.reflect.Field;

import org.datamanager.persistence.xml.XMLDataAccessObject;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.Text;

/**
 * handle boolean primitive
 *
 * @author xi rao & Jason Lynn Baumgartner
 */
public class BooleanFieldType
    implements FieldType
    {
    private String TRUE = "true";

    protected BooleanFieldType()
        {
        }

    /**
     * retore the state of array of an object from xml file
     * @param field represent the object's field
     * @param object represent the instance of any type of object
     * @param arrayNode XML element for reading state
     */
    public void restorePrimitiveArray(Field field, Object object, 
                                      Node arrayNode)
        {
        try
            {
            NodeList nodeList = arrayNode.getChildNodes();
            boolean[] array = new boolean[nodeList.getLength()];

            for (int i = 0; i < nodeList.getLength(); i++)
                {
                Node node = nodeList.item(i);
                array[i] = Boolean.getBoolean(node.getLastChild()
                                                  .getNodeValue());
                }

            field.set(object, array);
            }
        catch (IllegalAccessException iae)
            {
            }
        }

    /**
      * save the state of array of an object to xml file
      * @param field represent the object's field
      * @param object represent the instance of any type of object
      * @param parent the parent xml element for saveing state
     */
    public void persistPrimitiveArray(Field field, Object object, 
                                      Element parent)
        {
        try
            {
            Document ownerDocument = parent.getOwnerDocument();
            boolean[] booleanArray = (boolean[]) field.get(object);

            for (int i = 0; i < booleanArray.length; i++)
                {
                Element intElement = ownerDocument.createElement(
                                             XMLDataAccessObject.BOOLEAN);
                Text value = ownerDocument.createTextNode(String.valueOf(
                                                                  booleanArray[i]));
                intElement.appendChild(value);
                parent.appendChild(intElement);
                }
            }
        catch (IllegalAccessException iae)
            {
            }
        }

    /**
     * restore the state of primitive of an object from xml file
     * @param field field represent the object's filed
     * @param object represent the instance of any type of object
     * @param node xml element for reading state
     */
    public void setPrimitiveValue(Field field, Object object, Node node)
        {
        try
            {
            field.setBoolean(object, 
                             (TRUE.equalsIgnoreCase(node.getNodeValue())));
            }
        catch (IllegalAccessException iae)
            {
            }
        }
    }