package org.datamanager.kernel;

import java.util.Observable;
import java.util.Observer;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.datamanager.kernel.Simpleton;
///////////////////////////////////////////////////////////////////////////////
// 2002-10-03 cam
// Created with testConstructor() and testObservation().
///////////////////////////////////////////////////////////////////////////////
import org.datamanager.kernel.SimpletonList;

public class SimpletonListTester
    extends TestCase
    {
    public SimpletonListTester(String string)
        {
        super(string);
        }

    public static Test suite()
        {
        TestSuite suite = new TestSuite("SimpletonListTester");
        suite.addTest(new SimpletonListTester("testConstructor"));
        suite.addTest(new SimpletonListTester("testObservation"));

        return suite;
        }

    public void testConstructor()
        {
        MySimpleton mySimpleton = new MySimpleton();
        SimpletonList simpletonList = new SimpletonList();

        // the list should start empty
        assertEquals(0, simpletonList.size());

        // add something and make sure it's there.
        simpletonList.add(mySimpleton);
        assertEquals(1, simpletonList.size());
        assertSame(mySimpleton, simpletonList.get(0));
        }

    public void testObservation()
        {
        MyObserver myObserver = new MyObserver();
        SimpletonList simpletonList = new SimpletonList();
        MySimpleton mySimpleton = new MySimpleton();

        simpletonList.addObserver(myObserver);

        // make sure we didn't accidentally update prematurely
        assertEquals(0, myObserver.observationCount);

        // add something and make sure we get notified
        simpletonList.add(mySimpleton);
        assertEquals(1, myObserver.observationCount);

        // make sure we got notified of the correct object
        assertSame(simpletonList, myObserver.lastObservableObserved);

        // remove something and make sure we still get notified
        // and our count is correct
        simpletonList.remove(mySimpleton);
        assertEquals(0, simpletonList.size());
        assertEquals(2, myObserver.observationCount);
        }

    private class MySimpleton
        extends Simpleton
        {
        public void process()
            {
            // do nothing;
            }
        }

    private class MyObserver
        implements Observer
        {
        private int observationCount = 0;
        private Observable lastObservableObserved = null;

        public void update(Observable observable, Object object)
            {
            ++observationCount;
            lastObservableObserved = observable;
            }
        }
    }