///////////////////////////////////////////////////////////////////////////////
// 2002-10-03 cam
// Created so that we could run KnownSpace.
///////////////////////////////////////////////////////////////////////////////
// 2002-10-05 cam
// Made superfancy so that it displays an image.  You can now tell that it is
// actually doing something, which is handy for functional tests.  Please feel
// free to improve this.  Make it wacky, crazy.  Make it up like your fly
// hoopty.  Fringe, hydraulics, a boomin' system.  The works.
///////////////////////////////////////////////////////////////////////////////
package org.datamanager.kernel;

import java.awt.BorderLayout;
import java.awt.Image;
import java.awt.geom.AffineTransform;
import java.awt.image.AffineTransformOp;
import java.awt.image.BufferedImage;

import java.io.IOException;

import java.lang.Thread;

import java.net.URL;

import javax.imageio.ImageIO;

import javax.swing.ImageIcon;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.WindowConstants;

import org.datamanager.kernel.Simpleton;

/**
 * A Simpleton to demonstrate that KnownSpace works.
 *
 * @author Chris Dent
 * @author Matt Liggett
 */
public class TeamASimpleton
    extends Simpleton
    {
    /** The URL to the image this Simpleton displays. */
    private final static String KNOWNSPACE_IMAGE = "http://www.burningchrome.com:81/~cdent/dpmoin/kslogo.gif";
    /** This Simpleton's toplevel graphical element. */
    private JFrame frame;
    /** Label which will contain the image to be displayed. */
    private JLabel label;
    /** The thought-provoking image we display. */
    private BufferedImage image;

    /**
     * Displays a thought-provoking image onscreen and rotates it.
     */
    public void process()
        {
        makeFrame();
        frame.pack();
        frame.setVisible(true);

        double rotation = 0;

        while (frame.isShowing())
            {
            rotate(rotation);
            frame.update(frame.getGraphics());
            sleep(50);
            rotation = rotation + .1;
            }
        }

    private void rotate(double rotation)
        {
        AffineTransform rotationTransform = new AffineTransform();
        rotationTransform.rotate(rotation, image.getWidth() / 2, 
                                 image.getHeight() / 2);

        AffineTransformOp affineTransformOp = new AffineTransformOp(
                                                      rotationTransform, 
                                                      AffineTransformOp.TYPE_BILINEAR);

        BufferedImage newImage = new BufferedImage(image.getWidth(), 
                                                   image.getHeight(), 
                                                   image.getType());

        newImage = affineTransformOp.filter(image, null);
        label.setIcon(new ImageIcon(newImage));
        }

    /**
     * Grabs an image, makes it into an icon, and puts it into a newly
     * constructed frame.
     */
    private void makeFrame()
        {
        frame = new JFrame(getInformation().getName());
        frame.setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);

        image = null;

        try
            {
            URL url = new URL(KNOWNSPACE_IMAGE);

            image = ImageIO.read(url);
            }
        catch (IOException e)
            {
            // Should have a real error here
            }

        label = new JLabel(new ImageIcon(image));
        frame.getContentPane().add(label, BorderLayout.CENTER);
        }

    private void sleep(int ms)
        {
        try
            {
            Thread.sleep(ms);
            }
        catch (InterruptedException e)
            {
            }
        }
    }